(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common/http'), require('angular-i18next'), require('rxjs/operators')) :
    typeof define === 'function' && define.amd ? define('angular-i18next-error-interceptor', ['exports', '@angular/core', '@angular/common/http', 'angular-i18next', 'rxjs/operators'], factory) :
    (global = global || self, factory(global['angular-i18next-error-interceptor'] = {}, global.ng.core, global.ng.common.http, global.angularI18next, global.rxjs.operators));
}(this, (function (exports, core, http, angularI18next, operators) { 'use strict';

    var HTTP_STATUS_DICTIONARY = new core.InjectionToken('HTTP_STATUS_LOCALE_KEYS');

    var I18NextErrorInterceptor = /** @class */ (function () {
        function I18NextErrorInterceptor(injector // https://github.com/angular/angular/issues/18224
        ) {
            this.injector = injector;
            this.statusKeys = this.injector.get(HTTP_STATUS_DICTIONARY);
        }
        I18NextErrorInterceptor.prototype.intercept = function (req, next) {
            var _this = this;
            return next.handle(req).pipe(operators.tap(function (event) { }, function (err) {
                if (err instanceof http.HttpErrorResponse) {
                    _this.HandleErrorMessage(err);
                }
            }));
        };
        I18NextErrorInterceptor.prototype.HandleErrorMessage = function (errorResponse) {
            if (!errorResponse) {
                return errorResponse;
            }
            var errorEntity;
            // if error is object or json string that can be parsed
            try {
                if (errorResponse.error instanceof Object) {
                    errorEntity = errorResponse.error;
                }
                else {
                    errorEntity = JSON.parse(errorResponse.error);
                }
            }
            catch (ex) { }
            // if object got message: server localized message by himself (no need to translate)
            if (!(errorEntity && errorEntity.message)) {
                errorEntity = { message: this.GetLocalizedStatusMessage(errorResponse.status) };
            }
            // modify error response with client localized message
            return new http.HttpErrorResponse(Object.assign(errorResponse, { error: errorEntity }));
        };
        I18NextErrorInterceptor.prototype.GetLocalizedStatusMessage = function (status) {
            if (status === void 0) { status = undefined; }
            var i18nextService = this.injector.get(angularI18next.I18NEXT_SERVICE);
            var errorKey = this.statusKeys[status] || this.statusKeys.default;
            return i18nextService.t(errorKey);
        };
        return I18NextErrorInterceptor;
    }());
    I18NextErrorInterceptor.decorators = [
        { type: core.Injectable }
    ];
    I18NextErrorInterceptor.ctorParameters = function () { return [
        { type: core.Injector }
    ]; };

    var HttpErrorResponseMessage = /** @class */ (function () {
        function HttpErrorResponseMessage() {
        }
        HttpErrorResponseMessage.prototype.transform = function (httpErrorResp) {
            if (!httpErrorResp || !httpErrorResp.error) {
                return null;
            }
            return httpErrorResp.error.message;
        };
        return HttpErrorResponseMessage;
    }());
    HttpErrorResponseMessage.decorators = [
        { type: core.Injectable },
        { type: core.Pipe, args: [{
                    name: 'httpErrorResponseMessage',
                },] }
    ];

    var DEFAULT_STATUS_KEYS = {
        400: 'http_error:validation_error',
        401: 'http_error:not_authorized',
        403: 'http_error:access_denied',
        500: 'http_error:internal_server_error',
        'default': 'http_error:unknown_server_error'
    };
    var declarations = [
        HttpErrorResponseMessage
    ];
    var I18NextErrorInterceptorModule = /** @class */ (function () {
        function I18NextErrorInterceptorModule() {
        }
        I18NextErrorInterceptorModule.forRoot = function (httpStatusDictionary) {
            if (httpStatusDictionary === void 0) { httpStatusDictionary = null; }
            return {
                ngModule: I18NextErrorInterceptorModule,
                providers: [
                    {
                        provide: HTTP_STATUS_DICTIONARY,
                        useValue: httpStatusDictionary || DEFAULT_STATUS_KEYS
                    },
                    {
                        provide: http.HTTP_INTERCEPTORS,
                        useClass: I18NextErrorInterceptor,
                        multi: true
                    }
                ]
            };
        };
        return I18NextErrorInterceptorModule;
    }());
    I18NextErrorInterceptorModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        http.HttpClientModule
                    ],
                    declarations: declarations,
                    exports: declarations,
                    providers: [
                        HttpErrorResponseMessage
                    ]
                },] }
    ];

    /**
     * Generated bundle index. Do not edit.
     */

    exports.DEFAULT_STATUS_KEYS = DEFAULT_STATUS_KEYS;
    exports.HTTP_STATUS_DICTIONARY = HTTP_STATUS_DICTIONARY;
    exports.HttpErrorResponseMessage = HttpErrorResponseMessage;
    exports.I18NextErrorInterceptorModule = I18NextErrorInterceptorModule;
    exports.ɵa = I18NextErrorInterceptor;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=angular-i18next-error-interceptor.umd.js.map
